Welcome to gntplib — gntplib 0.5 documentation

# Welcome to gntplib

gntplib is a Growl Notification Transport Protocol (GNTP) client library in Python.

gntplib is tested on Python 2.7/3.2, Growl 1.3.3 and Growl for Windows 2.0.9.

- Installation
- Usage
  - Publish
    - Create a Publisher Instance
    - Register the Publisher Instance
    - Send a Notification
  - Subscribe
  - Icon
  - Callback
  - Security
    - Password
    - Encryption
  - Additional Headers
- Asynchronous Support
  - Publisher
  - Subscriber
  - Resource
- API
  - Simple Functions
    - `publish()`
    - `subscribe()`
  - Application Objects
    - `Publisher`
    - `Subscriber`
  - GNTP Client Object
    - `GNTPClient`
  - Notification Type Object
    - `Event`
  - Resource Objects
    - `Resource`
  - Socket Callback Object
    - `SocketCallback`